@@ -37,7 +37,7 @@ survdiff(Surv(surv_mm, death_cancer) ~ year8594, data=melanoma)
 survdiff(Surv(surv_mm, death_cancer) ~ year8594, data=melanoma, rho=1)
 
 ## @knitr d_crudeRates1000_agegrp
-survRate(Surv(surv_mm/1000,death_cancer)~year8594, data=melanoma)
+survRate(Surv(surv_mm/1000,death_cancer)~agegrp, data=melanoma)
 ## melanoma %>%
 ##     select(death_cancer, surv_mm, year8594) %>%
 ##     group_by(year8594) %>%
@@ -53,7 +53,7 @@ plot(mfit_agegrp, col = 1:4,
 legend("bottomleft", levels(melanoma$agegrp), col=1:4, lty = 1)
 
 ## @knitr e_crudeRates1000_agegrp
-mfit_agegrp_year <- survfit(Surv(surv_mm/12, death_cancer) ~ agegrp, data = melanoma)
+mfit_agegrp_year <- survfit(Surv(surv_mm/12/1000, death_cancer) ~ agegrp, data = melanoma)
 plot(mfit_agegrp_year, col = 1:4,
      xlab = "Years since diagnosis",
      ylab = "Survival",
